from ..BluetoothCodec import BluetoothCodec
from ..PtdBtDevice import PtdBtDevice
from ..PtdBtDevice import strip_response
from ..SerialMessage import SerialMessage
from ..BluetoothRole import BluetoothRole
from .RearPanelDataSource import RearPanelDataSource
from .RearPanelSamplingRate import RearPanelSamplingRate

class BTC_4149(PtdBtDevice):
    def __init__(self):
        super().__init__("BTC-4149", 32, 35)

    def set_rear_panel_data_source(self, source: RearPanelDataSource) -> None:
        message_type = SerialMessage.MSG_SET_REAR_PANEL_DATA_SOURCE
        payload = str(source.value)
        self._send_packet(message_type, payload)
        self._read_packet() # read the TransactionDone packet back from the device

    def get_rear_panel_data_source(self) -> RearPanelDataSource:
        message_type = SerialMessage.MSG_GET_REAR_PANEL_DATA_SOURCE
        payload = ""
        self._send_packet(message_type, payload)
        rear_panel_data_source_string = self._read_packet()
        return RearPanelDataSource[strip_response(rear_panel_data_source_string)]

    def set_bt_role(self, role: BluetoothRole) -> None:
        message_type = SerialMessage.MSG_SET_BT_ROLE
        payload = str(role.value)
        self._send_packet(message_type, payload)
        self._read_packet() # read the TransactionDone packet back from the device

    def set_rear_panel_audio_sampling_rate(self, rate: RearPanelSamplingRate) -> None:
        message_type = SerialMessage.MSG_SET_REAR_PANEL_AUDIO_SAMPLING_RATE
        payload = str(rate.value)
        self._send_packet(message_type, payload)
        self._read_packet() # read the TransactionDone packet back from the device

    def get_rear_panel_audio_sampling_rate(self) -> RearPanelSamplingRate:
        message_type = SerialMessage.MSG_GET_REAR_PANEL_AUDIO_SAMPLING_RATE
        payload = ""
        self._send_packet(message_type, payload)
        rear_panel_sampling_rate_string = self._read_packet()
        return RearPanelSamplingRate[f"REAR_PANEL_SR_{strip_response(rear_panel_sampling_rate_string)}"]
