from .BluetoothProfile import BluetoothProfile
from .BluetoothCodec import BluetoothCodec
from .AvrcpState import AvrcpState
from .HfpState import HfpState

class BluetoothLink:
    def __init__(self, mac_address: str):
        self._mac_address = mac_address

class A2dpLink(BluetoothLink):
    def __init__(self, mac_address: str, codec: BluetoothCodec, sampling_rate: int):
        super().__init__(mac_address)
        self._codec = codec
        self._sampling_rate = sampling_rate
    
    def get_codec(self) -> BluetoothCodec:
        return self._codec
    
    def get_sampling_rate(self) -> int:
        return self._sampling_rate

class AvrcpLink(BluetoothLink):
    def __init__(self, mac_address: str, state: AvrcpState):
        super().__init__(mac_address)
        self._state = state
    
    def get_state(self) -> AvrcpState:
        return self._state

class HfpLink(BluetoothLink):
    def __init__(self, mac_address: str, codec: BluetoothCodec, state: HfpState):
        super().__init__(mac_address)
        self._codec = codec
        self._state = state
    
    def get_codec(self) -> BluetoothCodec:
        return self._codec
    
    def get_state(self) -> HfpState:
        return self._state