import time
from PtdBtDevice import BTC_4149
from PtdBtDevice.BluetoothProfile import BluetoothProfile
from PtdBtDevice.BluetoothCallStatus import BluetoothCallStatus
from PtdBtDevice.exceptions import DeviceNotFoundException

device = None

try:
    device = BTC_4149()
except DeviceNotFoundException:
    print ("ERROR: No BTC-4149 devices found.")
    exit(-1)

print ("--DATA FROM DEVICE--")
print (f"Model #: {device.get_model().name.replace('_','-')}")
print (f"Firmware Version: {device.get_firmware_version()}")
print (f"Bluetooth Firmware Version: {device.get_bt_firmware_version()}")
print (f"Serial Number: {device.get_serial_number()}")
print (f"Manufacture Date: {device.get_manufacture_date()}")
print (f"Bluetooth Name: {device.get_bt_name()}")
print (f"Bluetooth Address: {device.get_bt_address()}")
print (f"Bluetooth Role: {device.get_bt_role().name}")
print (f"Rear Panel Data Source: {device.get_rear_panel_data_source().name}")
print (f"Rear Panel Audio Sampling Rate: {device.get_rear_panel_audio_sampling_rate().name}")
print (f"Current Bluetooth Profiles and Codecs:")
print (f"A2DP: {device.get_current_bt_codecs().get_a2dp_codec().name}")
print (f"HFP: {device.get_current_bt_codecs().get_hfp_codec().name}")
print (f"--PERFORMING 10 SECOND BLUETOOTH INQUIRY--")
devices_found = device.perform_bt_inquiry(10)
print (f"{len(devices_found)} device{'' if len(devices_found) == 1 else 's'} found{'.' if len(devices_found) == 0 else ':'}")
for detected_device in devices_found:
    print(f"MAC address: {detected_device.get_mac_address()}, name: {detected_device.get_friendly_name()}")
if len(devices_found) > 0:
    print (f"Attempting connection to {devices_found[0].get_friendly_name()}...")
    call_status = device.start_bt_connection(devices_found[0].get_mac_address(), BluetoothProfile.A2DP)
    if call_status == BluetoothCallStatus.CALL_STATUS_CONNECTED:
        print ("Connection succeeded.")
        print ("Waiting 5 seconds...")
        time.sleep(5)
        print ("Disconnecting...")
        device.disconnect_all()
        print ("Clearing paired device list...")
        device.clear_paired_device_list()
    else:
        print ("Connection failed.")
